<?php

namespace Drupal\taxonomy_term_depth\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Database\Connection;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Form class for deleting data form.
 */
class DepthDeleteDataForm extends FormBase {

  /**
   * Constructs a new DepthDeleteForm object.
   *
   * @param \Drupal\Core\Database\Connection $database
   *   The database connection.
   */
  public function __construct(
    protected Connection $database,
  ) {
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): static {
    return new static(
      $container->get('database')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'gathercontent_remove_local_data_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['remove_depth_field_data'] = [
      '#type' => 'Fieldset',
      '#title' => $this->t('Prepare Removing Depth Field Data.'),
      '#description' => $this->t('Clicking on this button will remove the depth field data.'),
    ];

    $form['remove_depth_field_data']['actions']['#type'] = 'actions';
    $form['remove_depth_field_data']['actions']['delete'] = [
      '#type' => 'submit',
      '#value' => $this->t('Delete data'),
      '#button_type' => 'primary',
      '#return_value' => 'submit',
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->database->update('taxonomy_term_field_data')
      ->fields([
        'depth_level' => NULL,
      ])
      ->execute();

    $this->messenger()->addMessage($this->t("Taxonomy depth fields' columns has been deleted."));
  }

}
